@@ -53,7 +53,7 @@ def corr_save_nii(corrs, affine, filename=None, corr_mask=get_HOcort(), size=[60
         If correct_method='FWE', here the FWE-correction will be used. If correct_methd='FDR', here the FDR-correction
         will be used. If correct_method=None, no correction.
         Only when p<1, correct_method works.
-    smooth : bool True or False
+    smooth : bool True or False. Default is True.
         Smooth the RSA result or not.
     plotrlt : bool True or False.
         Plot the RSA result automatically or not.
@@ -131,11 +131,11 @@ def corr_save_nii(corrs, affine, filename=None, corr_mask=get_HOcort(), size=[60
 
         # FDR-correction
         if correct_method == "FDR":
-            corrsp = fdr_correct(corrsp)
+            corrsp = fdr_correct(corrsp, p_threshold=p)
 
         # FWE-correction
         if correct_method == "FWE":
-            corrsp = fwe_correct(corrsp)
+            corrsp = fwe_correct(corrsp, p_threshold=p)
 
     # iterate through all the calculation units again
 
@@ -204,17 +204,17 @@ def corr_save_nii(corrs, affine, filename=None, corr_mask=get_HOcort(), size=[60
 
         mask_to(get_bg_ch2bet(), size, affine, filename=filename)
         mask = nib.load(filename).get_fdata()
-        print(mask.shape)
 
     else:
         # load the array data of the mask file
         mask = nib.load(corr_mask).get_fdata()
 
-        # do correction by the mask
+    # do correction by the mask
+    if corr_mask != None:
         for i in range(nx):
             for j in range(ny):
                 for k in range(nz):
-                    if (math.isnan(mask[i, j, k]) == True) or mask[i, j, k] == 0:
+                    if (math.isnan(mask[i, j, k]) is True) or mask[i, j, k] == 0:
                         newimg_nii[i, j, k] = np.nan
 
     print(filename)
@@ -461,31 +461,24 @@ def stats_save_nii(corrs, affine, filename=None, corr_mask=get_HOcort(), size=[6
     # in order to avoid results showing outside of the brain
     if corr_mask == get_HOcort():
 
-        mask_to(get_bg_ch2bet(), filename, size, affine)
+        mask_to(get_bg_ch2bet(), size, affine, filename)
         mask = nib.load(filename).get_fdata()
-        print(mask.shape)
 
     else:
         # load the array data of the mask file
         mask = nib.load(corr_mask).get_fdata()
 
-        # do correction by the mask
+    # do correction by the mask
+    if corr_mask != None:
         for i in range(nx):
             for j in range(ny):
                 for k in range(nz):
-                    if (math.isnan(mask[i, j, k]) == True) or mask[i, j, k] == 0:
+                    if (math.isnan(mask[i, j, k]) is True) or mask[i, j, k] == 0:
+                        newimg_nii[i, j, k] = np.nan
+                    if newimg_nii[i, j, k] < t_threshold and newimg_nii[i, j, k] > 0:
+                        newimg_nii[i, j, k] = np.nan
+                    if newimg_nii[i, j, k] > -t_threshold and newimg_nii[i, j, k] < 0:
                         newimg_nii[i, j, k] = np.nan
-
-    # do correction by the mask
-    for i in range(nx):
-        for j in range(ny):
-            for k in range(nz):
-                if (math.isnan(mask[i, j, k]) == True) or mask[i, j, k] == 0:
-                    newimg_nii[i, j, k] = np.nan
-                if newimg_nii[i, j, k] < t_threshold and newimg_nii[i, j, k] > 0:
-                    newimg_nii[i, j, k] = np.nan
-                if newimg_nii[i, j, k] > -t_threshold and newimg_nii[i, j, k] < 0:
-                    newimg_nii[i, j, k] = np.nan
 
     print(filename)
 
