@@ -336,16 +336,16 @@ def plot_corrs_by_time(corrs, labels=None, time_unit=[0, 0.1]):
     return 0
 
 
-def plot_tbytsim_withstats(Similarities, start_time=0, end_time=1, color='r', lim=[-0.1, 0.8]):
+def plot_tbytsim_withstats(similarities, start_time=0, end_time=1, color='r', lim=[-0.1, 0.8]):
 
     """
-    Plot the time-by-time Similarities averaging all subjects
+    Plot the time-by-time Similarities
 
     Parameters
     ----------
-    Similarities : array
+    similarities : array
         The Similarities.
-        The size of Similarities should be [n_subs, n_ts] or [n_subs, n_ts, 2]. n_subs, n_ts represent the number of
+        The size of similarities should be [n_subs, n_ts] or [n_subs, n_ts, 2]. n_subs, n_ts represent the number of
         subjects and number of time-points. 2 represents the similarity and a p-value.
     start_time : int or float. Default is 0.
         The start time.
@@ -357,20 +357,20 @@ def plot_tbytsim_withstats(Similarities, start_time=0, end_time=1, color='r', li
         The corrs view lims.
     """
 
-    if len(np.shape(Similarities)) < 2 or len(np.shape(Similarities)) > 3:
+    if len(np.shape(similarities)) < 2 or len(np.shape(similarities)) > 3:
 
         return "Invalid input!"
 
-    n = len(np.shape(Similarities))
+    n = len(np.shape(similarities))
 
     minlim = lim[0]
     maxlim = lim[1]
 
     if n == 3:
-        Similarities = Similarities[:, :, 0]
+        similarities = similarities[:, :, 0]
 
-    nsubs = np.shape(Similarities)[0]
-    nts = np.shape(Similarities)[1]
+    nsubs = np.shape(similarities)[0]
+    nts = np.shape(similarities)[1]
 
     tstep = float((end_time-start_time)/nts)
 
@@ -378,23 +378,23 @@ def plot_tbytsim_withstats(Similarities, start_time=0, end_time=1, color='r', li
         for t in range(nts):
 
             if t<=1:
-                Similarities[sub, t] = np.average(Similarities[sub, :t+3])
+                similarities[sub, t] = np.average(similarities[sub, :t+3])
             if t>1 and t<(nts-2):
-                Similarities[sub, t] = np.average(Similarities[sub, t-2:t+3])
+                similarities[sub, t] = np.average(similarities[sub, t-2:t+3])
             if t>=(nts-2):
-                Similarities[sub, t] = np.average(Similarities[sub, t-2:])
+                similarities[sub, t] = np.average(similarities[sub, t-2:])
 
-    avg = np.average(Similarities, axis=0)
+    avg = np.average(similarities, axis=0)
     err = np.zeros([nts], dtype=np.float)
 
     for t in range(nts):
-        err[t] = np.std(Similarities[:, t], ddof=1)/np.sqrt(nsubs)
+        err[t] = np.std(similarities[:, t], ddof=1)/np.sqrt(nsubs)
 
     ps = np.zeros([nts], dtype=np.float)
     chance = np.full([nsubs], 0)
 
     for t in range(nts):
-        ps[t] = permutation_test(Similarities[:, t], chance)
+        ps[t] = permutation_test(similarities[:, t], chance)
         if ps[t] < 0.05 and avg[t] > 0:
             plt.plot(t*tstep+start_time, maxlim*0.9, 's', color=color, alpha=1)
             xi = [t*tstep+start_time, t*tstep+tstep+start_time]
@@ -528,9 +528,9 @@ def plot_corrs_hotmap(corrs, chllabels=None, time_unit=[0, 0.1], lim=[0, 1], smo
     limmax = lim[1]
 
     if cmap == None:
-        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls*0.16), clim=(limmin, limmax), origin='low', cmap='inferno')
+        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls*0.16), clim=(limmin, limmax), origin='lower', cmap='inferno')
     else:
-        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls * 0.16), clim=(limmin, limmax), origin='low', cmap=cmap)
+        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls * 0.16), clim=(limmin, limmax), origin='lower', cmap=cmap)
 
     fig = plt.gcf()
     size = fig.get_size_inches()
@@ -729,10 +729,11 @@ def plot_corrs_hotmap_stats(corrs, stats, chllabels=None, time_unit=[0, 0.1], li
     limmin = lim[0]
     limmax = lim[1]
 
+
     if cmap == None:
-        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls*0.16), clim=(limmin, limmax), origin='low', cmap='inferno')
+        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls*0.16), clim=(limmin, limmax), origin='lower', cmap='inferno')
     else:
-        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls * 0.16), clim=(limmin, limmax), origin='low', cmap=cmap)
+        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls * 0.16), clim=(limmin, limmax), origin='lower', cmap=cmap)
 
     fig = plt.gcf()
     size = fig.get_size_inches()
@@ -869,9 +870,9 @@ def plot_nps_hotmap(similarities, chllabels=None, time_unit=[0, 0.1], lim=[0, 1]
     limmax = lim[1]
 
     if cmap == None:
-        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls*0.16), clim=(limmin, limmax), origin='low')
+        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls*0.16), clim=(limmin, limmax), origin='lower')
     else:
-        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls * 0.16), clim=(limmin, limmax), origin='low', cmap=cmap)
+        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls * 0.16), clim=(limmin, limmax), origin='lower', cmap=cmap)
 
     fig = plt.gcf()
     size = fig.get_size_inches()
@@ -1070,9 +1071,9 @@ def plot_stats_hotmap(stats, chllabels=None, time_unit=[0, 0.1], lim=[-7, 7], sm
     fig.set_size_inches(size_x, size_y)
 
     if cmap == None:
-        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls*0.16), clim=(limmin, limmax), origin='low')
+        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls*0.16), clim=(limmin, limmax), origin='lower')
     else:
-        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls * 0.16), clim=(limmin, limmax), origin='low', cmap=cmap)
+        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls * 0.16), clim=(limmin, limmax), origin='lower', cmap=cmap)
 
     cb = plt.colorbar()
     cb.ax.tick_params(labelsize=16)
@@ -1381,4 +1382,4 @@ def plot_brainrsa_rlts(img, threshold=None, slice=[6, 6, 6], background=None, ty
 
             plot_brainrsa_surface(img, threshold=threshold, type=type)
 
-    return 0
+    return 0
\ No newline at end of file
