@@ -8,9 +8,8 @@ import nibabel as nib
 import numpy as np
 import os
 import math
-from scipy.stats import spearmanr
-from scipy.stats import pearsonr
-from scipy.stats import kendalltau
+from scipy.stats import spearmanr, pearsonr, kendalltau, ttest_1samp, ttest_rel
+import sys
 
 # get package abspath
 package_root = os.path.dirname(os.path.abspath(__file__))
@@ -130,7 +129,7 @@ def fwe_correct(p, p_threshold):
         for j in range(py):
             for k in range(pz):
 
-                if (math.isnan(p[i, j, k]) == False) and (p[i, j, k] < p_threshold):
+                if (math.isnan(p[i, j, k]) == False):
                     n = n + 1
 
     fwep = p*n
@@ -170,7 +169,7 @@ def fdr_correct(p, p_threshold):
         for j in range(py):
             for k in range(pz):
 
-                if (math.isnan(p[i, j, k]) == False) and (p[i, j, k] < p_threshold):
+                if (math.isnan(p[i, j, k]) == False):
 
                     n = n + 1
 
@@ -184,7 +183,7 @@ def fdr_correct(p, p_threshold):
         for j in range(py):
             for k in range(pz):
 
-                if (math.isnan(p[i, j, k]) == False) and (p[i, j, k] < p_threshold):
+                if (math.isnan(p[i, j, k]) == False):
                     pcluster[m] = p[i, j, k]
                     m = m + 1
 
@@ -578,8 +577,14 @@ def mask_to(mask, size, affine, filename=None):
     ny = data.shape[1]
     nz = data.shape[2]
 
+    print("******")
+    print(nx, ny, nz)
+
     maskaffine = nib.load(mask).affine
 
+    print(maskaffine)
+    print(maskaffine[0, 0], maskaffine[1, 1], maskaffine[2, 2])
+
     newdata = np.zeros(size, dtype=np.float)
 
     for i in range(nx):
@@ -592,8 +597,8 @@ def mask_to(mask, size, affine, filename=None):
                     x = int(float((mx-affine[0, 3])/affine[0, 0]))+1
                     y = int(float((my-affine[1, 3])/affine[1, 1]))+1
                     z = int(float((mz-affine[2, 3])/affine[2, 2]))+1
-                    if x<size[0] and y<size[1] and z<size[2]:
-                        newdata[x, y, z] = 1
+                    if x < size[0] and y < size[1] and z < size[2]:
+                        newdata[x, y, z] = data[i, j, k]
 
     file = nib.Nifti1Image(newdata, affine)
 
@@ -732,4 +737,279 @@ def permutation_corr(v1, v2, method="spearman", iter=5000):
 
     p = np.float64((ni+1)/(iter+1))
 
-    return p
\ No newline at end of file
+    return p
+
+
+' a function for getting the cluster-index information '
+
+def get_cluster_index_1d_1sided(m):
+
+    """
+    Get cluster-index information from a vector
+
+    Parameters
+    ----------
+    m : array
+        A significant vector.
+        The values in m should be 0 or 1, which represent significant point or not significant point.
+
+    Returns
+    -------
+    p : float
+        The permutation test result, p-value.
+    """
+
+    x = np.shape(m)[0]
+    b = np.zeros([x+2])
+    b[1:x+1] = m
+
+    index_m = np.zeros([x])
+
+    index_n = 0
+    for i in range(x):
+        if b[i+1] == 1 and b[i] == 0 and b[i+2] == 1:
+            index_n = index_n + 1
+        if b[i+1] == 1:
+            if b[i] != 0 or b[i+2] != 0:
+                index_m[i] = index_n
+
+    return index_m, index_n
+
+
+' a function for getting the cluster-index information '
+
+def get_cluster_index_2d_1sided(m):
+
+    """
+    Get cluster-index information from a matrix
+
+    Parameters
+    ----------
+    m : array
+        A significant matrix.
+        The values in m should be 0 or 1, which represent significant point or not significant point.
+
+    Returns
+    -------
+    p : float
+        The permutation test result, p-value.
+    """
+
+    x, y = np.shape(m)
+    b = np.zeros([x+2, y+2])
+    b[1:x+1, 1:y+1] = m
+
+    index_m = np.zeros([x, y])
+
+    index_n = 0
+    for i in range(x):
+        for j in range(y):
+            ii = i + 1
+            jj = j + 1
+            if b[ii, jj] == 1 and (b[ii-1, jj]+b[ii+1, jj]+b[ii, jj-1]+b[ii, jj+1]) != 0:
+                min_index = index_n + 1
+                if b[ii - 1, jj] == 1:
+                    min_index = np.min([min_index, index_m[i - 1, j]])
+                if b[ii, jj - 1] == 1:
+                    min_index = np.min([min_index, index_m[i, j - 1]])
+                k1 = 0
+                while b[ii, jj - k1] == 1:
+                    index_m[i, j - k1] = min_index
+                    k1 = k1 + 1
+                k2 = 0
+                while b[ii - k2, jj] == 1:
+                    index_m[i - k2, j] = min_index
+                    k2 = k2 + 1
+                k = 0
+                while b[ii, jj + k] == 1:
+                    index_m[i, j + k] = min_index
+                    k = k + 1
+                k = 0
+                while b[ii + k, jj] == 1:
+                    index_m[i + k, j] = min_index
+                    k = k + 1
+                if b[ii, jj - 1] != 1:
+                    index_n = index_n + 1
+                    k = 0
+                    m = 0
+                    while b[ii, jj + k] == 1:
+                        if b[ii - 1, jj + k] == 1:
+                            m = 1
+                        k = k + 1
+                    if m == 1:
+                        index_n = index_n - 1
+
+    return index_m, index_n
+
+
+' a function for 1-sample & 1-sided cluster based permutation test for 2-D results '
+
+def clusterbased_permutation_2d_1samp_1sided(results, level=0, p_threshold=0.05, iter=5000):
+
+    """
+    1-sample & 1-sided cluster based permutation test for 2-D results
+
+    Parameters
+    ----------
+    results : array
+        A result matrix.
+        The shape of results should be [n_subs, x1, x2]. n_subs represents the number of subjects.
+    level : float. Default is 0.
+        A expected value in null hypothesis. (Here, results > level)
+    p_threshold : float. Default is 0.05.
+        The threshold of p-values.
+    iter : int. Default is 5000.
+        The times for iteration.
+
+    Returns
+    -------
+    p : float
+        The permutation test result, p-value.
+    """
+
+    nsubs, x1, x2 = np.shape(results)
+
+    ps = np.zeros([x1, x2])
+    ts = np.zeros([x1, x2])
+    for t1 in range(x1):
+        for t2 in range(x2):
+            ts[t1, t2], p = ttest_1samp(results[:, t1, t2], level, alternative='greater')
+            if p < p_threshold and ts[t1, t2] > 0:
+                ps[t1, t2] = 1
+            else:
+                ps[t1, t2] = 0
+
+    cluster_index, cluster_n = get_cluster_index_2d_1sided(ps)
+    print(cluster_n)
+
+    if cluster_n != 0:
+        cluster_ts = np.zeros([cluster_n])
+        for i in range(cluster_n):
+            for t1 in range(x1):
+                for t2 in range(x2):
+                    if cluster_index[t1, t2] == i + 1:
+                        cluster_ts[i] = cluster_ts[i] + ts[t1, t2]
+
+        permu_ts = np.zeros([iter])
+        chance = np.full([nsubs], level)
+        for i in range(iter):
+            permu_cluster_ts = np.zeros([cluster_n])
+            for j in range(cluster_n):
+                for t1 in range(x1):
+                    for t2 in range(x2):
+                        if cluster_index[t1, t2] == j + 1:
+                            v = np.hstack((results[:, t1, t2], chance))
+                            vshuffle = np.random.permutation(v)
+                            v1 = vshuffle[:nsubs]
+                            v2 = vshuffle[nsubs:]
+                            permu_cluster_ts[j] = permu_cluster_ts[j] + ttest_rel(v1, v2, alternative="greater")[0]
+            permu_ts[i] = np.max(permu_cluster_ts)
+
+        for i in range(cluster_n):
+            index = 0
+            for j in range(iter):
+                if cluster_ts[i] > permu_ts[j]:
+                    index = index + 1
+            if index < iter * (1-p_threshold):
+                for t1 in range(x1):
+                    for t2 in range(x2):
+                        if cluster_index[t1, t2] == i + 1:
+                            ps[t1, t2] = 0
+
+    return ps
+
+
+' a function for 1-sided cluster based permutation test for 2-D results '
+
+def clusterbased_permutation_2d_1sided(results1, results2, p_threshold=0.05, iter=5000):
+
+    """
+    1-sided cluster based permutation test for 2-D results
+
+    Parameters
+    ----------
+    results1 : array
+        A result matrix under condition1.
+        The shape of results should be [n_subs, x1, x2]. n_subs represents the number of subjects.
+    results2 : array
+        A result matrix under condition2.
+        The shape of results should be [n_subs, x1, x2]. n_subs represents the number of subjects. (results1 > results2)
+    p_threshold : float. Default is 0.05.
+        The threshold of p-values.
+    iter : int. Default is 5000.
+        The times for iteration.
+
+    Returns
+    -------
+    p : float
+        The permutation test result, p-value.
+    """
+
+    nsubs1, x11, x12 = np.shape(results1)
+    nsubs2, x21, x22 = np.shape(results2)
+
+    if nsubs1 != nsubs2 and x11 != x21 and x12 != x22:
+
+        return "Invalid input!"
+
+    nsubs = nsubs1
+    x1 = x11
+    x2 = x12
+
+    ps = np.zeros([x1, x2])
+    ts = np.zeros([x1, x2])
+    for t1 in range(x1):
+        for t2 in range(x2):
+            ts[t1, t2], p = ttest_rel(results1[:, t1, t2], results2[:, t1, t2], alternative="greater")
+            if p < p_threshold and ts[t1, t2] > 0:
+                ps[t1, t2] = 1
+            else:
+                ps[t1, t2] = 0
+
+    cluster_index, cluster_n = get_cluster_index_2d_1sided(ps)
+    print(cluster_n)
+
+    if cluster_n != 0:
+        cluster_ts = np.zeros([cluster_n])
+        for i in range(cluster_n):
+            for t1 in range(x1):
+                for t2 in range(x2):
+                    if cluster_index[t1, t2] == i + 1:
+                        cluster_ts[i] = cluster_ts[i] + ts[t1, t2]
+
+        permu_ts = np.zeros([iter])
+        for i in range(iter):
+            permu_cluster_ts = np.zeros([cluster_n])
+            for j in range(cluster_n):
+                for t1 in range(x1):
+                    for t2 in range(x2):
+                        if cluster_index[t1, t2] == j + 1:
+                            v = np.hstack((results1[:, t1, t2], results2[:, t1, t2]))
+                            vshuffle = np.random.permutation(v)
+                            v1 = vshuffle[:nsubs]
+                            v2 = vshuffle[nsubs:]
+                            permu_cluster_ts[j] = permu_cluster_ts[j] + ttest_rel(v1, v2, alternative="greater")[0]
+            permu_ts[i] = np.max(permu_cluster_ts)
+
+        for i in range(cluster_n):
+            index = 0
+            for j in range(iter):
+                if cluster_ts[i] > permu_ts[j]:
+                    index = index + 1
+            if index < iter * (1 - p_threshold):
+                for t1 in range(x1):
+                    for t2 in range(x2):
+                        if cluster_index[t1, t2] == i + 1:
+                            ps[t1, t2] = 0
+
+    return ps
+
+
+' a function for showing the progress bar '
+
+def show_progressbar(str, cur, total=100):
+
+    percent = '{:.2%}'.format(cur / total)
+    sys.stdout.write('\r')
+    sys.stdout.write(str + ": [%-100s] %s" % ('=' * int(cur), percent))
+    sys.stdout.flush()
\ No newline at end of file
